]> mj.ucw.cz Git - ursary.git/blobdiff - ursaryd.c
Generalized glue between LibUSB and LibUCW mainloop
[ursary.git] / ursaryd.c
index ddc896f8062b64fe58c878c8420aecb010312134..8df65df31a8493eee81ea6cb22a0889c6e453ede 100644 (file)
--- a/ursaryd.c
+++ b/ursaryd.c
@@ -1,7 +1,7 @@
 /*
  *     The Ursary Audio Controls
  *
- *     (c) 2014--2018 Martin Mares <mj@ucw.cz>
+ *     (c) 2014--2020 Martin Mares <mj@ucw.cz>
  */
 
 #undef LOCAL_DEBUG
 #include <syslog.h>
 
 #include "ursaryd.h"
+#include "usb.h"
 
 /*
  *     Map of all controls
  *
  *             rotary          red button      green button
*     0       sink Brum       mute            -
  *     1       -               -               -
  *     2       -               -               -
  *     3       -               -               -
- *     4       MPD             mute            play/pause/stop
- *     5       Albireo MPV     mute            -
- *     6       Albireo other   mute            -
- *     7       other machines  mute            -
+ *     4       MPD             mute            MPD play/pause
+ *     5       Albireo MPV     mute            MPD stop
+ *     6       Albireo other   mute            MPD prev
+ *     7       other machines  mute            MPD next
  *
  *     center  -
  *     slider  -
  */
 
+#define PCH_SINK "alsa_output.pci-0000_00_1f.3.analog-stereo"
+
 /*** Sink controls ***/
 
 static double volume_from_pa(pa_volume_t vol)
@@ -288,6 +291,8 @@ static void update_group_from_button(int i, int on)
     }
 }
 
+#if 0  // Not used at the moment
+
 static int find_touched_client(void)
 {
   int touched = -1;
@@ -302,8 +307,12 @@ static int find_touched_client(void)
   return touched;
 }
 
+#endif
+
 /*** Default sink controls ***/
 
+#if 0  // Not mapped to any button at the moment
+
 static const char *get_client_sink(int i)
 {
   const char *sink = NULL;
@@ -414,6 +423,8 @@ static void update_default_sink_from_button(int button, int on)
     }
 }
 
+#endif
+
 /*** MPD controls ***/
 
 static bool mpd_flash_state;
@@ -596,8 +607,8 @@ static void do_update(struct main_timer *t)
     }
 
   // Everything normal
-  update_ring_from_sink(0, "alsa_output.brum.analog-stereo");
-  update_button_from_port(8, "alsa_output.brum.analog-stereo", "analog-output-headphones");
+  update_ring_from_sink(0, PCH_SINK);
+  update_button_from_port(8, PCH_SINK, "analog-output-headphones");
   update_groups();
 #if 0
   update_default_sink();
@@ -636,7 +647,7 @@ void notify_rotary(int rotary, int delta)
   switch (rotary)
     {
     case 0:
-      update_sink_from_rotary(delta, "alsa_output.brum.analog-stereo");
+      update_sink_from_rotary(delta, PCH_SINK);
       break;
     default:
       update_group_from_rotary(rotary, delta);
@@ -651,10 +662,10 @@ void notify_button(int button, int on)
   switch (button)
     {
     case 0:
-      update_sink_mute_from_button(on, "alsa_output.brum.analog-stereo");
+      update_sink_mute_from_button(on, PCH_SINK);
       break;
     case 8:
-      update_port_from_button(on, "alsa_output.brum.analog-stereo", "analog-output-lineout", "analog-output-headphones");
+      update_port_from_button(on, PCH_SINK, "analog-output-lineout", "analog-output-headphones");
       break;
 #if 0
     case 9:
@@ -719,6 +730,7 @@ static void daemon_body(struct daemon_params *dp)
   main_init();
   update_timer.handler = do_update;
 
+  usb_init();
   noct_init();
   pulse_init();
   mpd_init();
@@ -1,7 +1,7 @@
  *
  *             rotary          red button      green button
- *     0       sink Brum       mute            -
+ *     0       sink PCH        mute            use headphones
  *     1       -               -               -
  *     2       -               -               -